/*
 *  defs.c: tables
 *
 *  Copyright (C) 2010- John Coppens (john@jcoppens.com)        
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 3 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *  
 *  You should have received a copy of the GNU Library General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "defs.h"

char	*conv_lengths[] = {
  "Angstroms {Å}",
  "Astronomical Units {AU}",
  "Atomic Unit {au, a0, b}",
  "Attometers {am}",
  "Barley Corn {barley_corn}",
  "Cable Lengths (U.S.)",
  "Cable Lengths (International)",
  "Cable Lengths (Imperial)",
  "Calibre {cal}",
  "Centimeters {cm}",
  "Chains (Gunter's) {ch}",
  "Chains (Ramsden's)",
  "Cubits {cubit}",
  "Decameters {dam}",
  "Decimeters {dm}",
  "ell {ell}",
  "Exameters {Em}",
  "Fathoms {fth}",
  "Fermis (femtometer) {fm}",
  "Fingers",
  "Fingers (cloth)",
  "Feet {ft}",
  "Feet (U.S. Survey)",
  "Furlongs {fur}",
  "Geographic Mile",
  "Gigameters {Gm}",
  "Hands",
  "Hectometers {hm}",
  "Inches {in}",
  "Inches (U.S. Survey)",
  "Kilometers {km}",
  "Leagues {lea}",
  "Light-second",
  "Light-minute",
  "Light-hour",
  "Light-day",
  "Light-years {ly}",
  "Lines {ln}",
  "Links {lnk}",
  "Links (Surveyor's)",
  "Megameters {Mm}",
  "Meters {m}",
  "Mickeys {mickey}",
  "Microinches {mci}",
  "Micrometers {µm}",
  "Microns {µ}",
  "Mils",
  "Miles {mi}",
  "Miles (U.S. Survey)",
  "Millimeters {mm}",
  "Nautical Leagues {NL}",
  "Nautical Miles {nmi}",
  "Nautical Miles (Admiralty)",
  "Nanometers {nm}",
  "Paces",
  "Palms",
  "Parsec",
  "Petameters {Pm}",
  "Pica {pi}",
  "Pica (French)",
  "Pica (American)",
  "Picometer {pm}",
  "Points (DTP) {pt}",
  "Points (Johnson)",
  "Points (Trebuchet)",
  "Points (Fournier)",
  "Points (Didot)",
  "Quarters",
  "Rods {rd}",
  "Ropes",
  "Spans",
  "Spans (cloth)",
  "Spat {S}",
  "Sticks",
  "Stigma",
  "Telegraph Mile",
  "Terameters {Tm}",
  "Twips",
  "Varas",
  "X Unit (= Siegbahn) {xu}",
  "Yards {yd}",
  "Yoctometers {ym}",
  "Yottameters {Ym}",
  "Zeptometers {zm}",
  "Zettameters {Zm}",
  NULL
};

char	*conv_areas[] = {
  "Acre {ac}",
  "Acre (Commercial)",
  "Acre (Irish)",
  "Acre (U.S. Survey)",
  "Are {a}",
  "Barn {b}",
  "Barony",
  "Base boxe",
  "Board {bd}",
  "Boiler Horsepower Equivalent Direct Radiation",
  "Bin (Taiwan)",
  "Bu (Japan)",
  "Cantero (Ecuador)",
  "Cao (Vietnam)",
  "Centaire {ca}",
  "Circular Inch {circ_in}",
  "Circular Mil {circ_mil}",
  "Circular Thou {circ_thou}",
  "Colpa (Ireland)",
  "Cord",
  "Dunam",
  "Hectare {ha}",
  "Hide",
  "Labor (Canada)",
  "Labor (US)",
  "Manzana (Costa Rica)",
  "Manzana (Argentina)",
  "Rai (Thailand)",
  "Rood",
  "Sao (Vietnam)",
  "Scruple (ancient Rome)",
  "Section (US Survey) {sec}",
  "Square {sq}",
  "Square (Sri Lanka)",
  "Square Attometer {sq.am}",
  "Square Caliber {cal2}",
  "Square Centimeter {cm2}",
  "Square Chain {chain2}",
  "Square Digit",
  "Square Decameter {dam2}",
  "Square Decimeter {dm2}",
  "Square Exameter {Em2}",
  "Square Femtometer {fm2}",
  "Square Foot {sqft}",
  "Square Foot (U.S. Survey)",
  "Square Gigameter {Gm2}",
  "Square Hectometer {hm2}",
  "Square Inch {in2}",
  "Square Inch (U.S. Survey)",
  "Square Kilometer {km2}",
  "Square Link",
  "Square Megameter {Mm2}",
  "Square Meter {m2}",
  "Square Mil {mil2}",
  "Square Mile {sq.mi.}",
  "Square Mile (U.S. Survey)",
  "Square Millimeter {mm2}",
  "Square Micrometer {µm2}",
  "Square Nanometer {nm2}",
  "Square Petameter {Pm2}",
  "Square Picometer {pm2}",
  "Square Rod {rd2}",
  "Square Pole {sq.pole}",
  "Square Perch {sq.perch}",
  "Square Terameter {Tm2}",
  "Square Thou {mil2}",
  "Square Yoctometer {ym2}",
  "Square Yottameter {Ym2}",
  "Square Zeptometer {zm2}",
  "Square Zettameter {Zm2}",
  "Square Yard {sq.yd.}",
  "Stremma",
  "Township",
  "Yardland",
  NULL
};

char	*conv_volumes[] = {
  "#2.5 can",
  "#10 can",
  "Acre-inch {ac.in.}",
  "Acre-foot {ac.ft.}",
  "Attoliter {al}",
  "Bag",
  "Barrel (U.S. dry) {bbl}",
  "Barrel (U.S. fluid)",
  "Barrel (petroleum) {bl}",
  "Barrel (Imperial)",
  "Beer Gallon",
  "Breakfast Cup",
  "Board Foot {fbm}",
  "Bucket {bkt}",
  "Bushel (U.S. dry level)",
  "Bushel (Imperial)",
  "Bushel (U.S. dry heaped)",
  "Butt",
  "Centiliter {cl}",
  "Coffeespoon",
  "Cooking Milliliter",
  "Coomb",
  "Cord (firewood) {cd}",
  "Cord Foot (timber) {cd_ft}",
  "Cubic Centimeter {cm3}",
  "Cubic Decimeter {dm3}",
  "Cubic Exameter {Em3}",
  "Cubic Fathom {fm3}",
  "Cubic Femtometer",
  "Cubic Foot {cu.ft.}",
  "Cubic Gigameter {Gm3}",
  "Cubic Inch {cu.in.}",
  "Cubic Kilometer {km3}",
  "Cubic Meter {m3}",
  "Cubic Megameter {Mm3}",
  "Cubic Micrometer {µm3}",
  "Cubic Mile {mi3}",
  "Cubic Millimeter {mm3}",
  "Cubic Nanometer {nm3}",
  "Cubic Petameter {Pm3}",
  "Cubic Picometer {pm3}",
  "Cubic Terameter {Tm3}",
  "Cubic Yard {cu.yd.}",
  "Cubic Yottameters {Ym3}",
  "Cubic Zettameters {Zm3}",
  "Cup (Canadian)",
  "Cup (US)",
  "Cup (metric)",
  "Dash (U.S.) {ds}",
  "Dash (Imperial)",
  "Decaliter {dal}",
  "Deciliter {dl}",
  "Dessertspoon",
  "Drop",
  "Drop (U.S.) {gtt}",
  "Drop (medical)",
  "Drop (Imperial)",
  "Exaliter {El}",
  "Femtoliter {fl}",
  "Fifth",
  "Firkin",
  "Fluid Drachm {fl.dr.}",
  "Fluid Dram {fl.dram}",
  "Fluid Ounce (U.S.) {fl.oz.}",
  "Fluid Ounce (Imperial)",
  "Fluid Scruple {fl.s.}",
  "Gallon (U.S. fluid) {gal}",
  "Gallon (U.S. dry)",
  "Gallon (Imperial)",
  "Gigaliter {Gl}",
  "Gill (U.S.) {gi}",
  "Gill (Imperial)",
  "Hectoliter {hl}",
  "Hogshead (U.S.) {hhd}",
  "Hogshead (Imperial)",
  "Jigger",
  "Kilderkin",
  "Kiloliter {kl}",
  "Lambda",
  "Last",
  "Liter {l}",
  "Load",
  "Measure",
  "Megaliter {Ml}",
  "Microliter {µl}",
  "Milliliter {ml}",
  "Minim (Imperial)",
  "Minim (U.S.) {minim.US}",
  "Nanoliter {nl}",
  "Nipperkin (US)",
  "Noggin {nog}",
  "Pail",
  "Picoliter {pl}",
  "Pint (U.S. fluid) {pt}",
  "Pint (U.S. dry)",
  "Pint (Imperial)",
  "Peck (U.S.) {pk}",
  "Peck (Imperial)",
  "Perch {per}",
  "Petaliter {Pl}",
  "Pinch (U.S.)",
  "Pinch (Imperial)",
  "Pipe",
  "Pony",
  "Pottle",
  "Quart (U.S. fluid) {qt}",
  "Quart (U.S. dry)",
  "Quart (Imperial)",
  "Quarter {qtr}",
  "Quatern",
  "Sack (U.S.)",
  "Sack (Imperial)",
  "Seam",
  "Stere {st}",
  "Strike (U.S.)",
  "Strike (Imperial)",
  "Shot",
  "Tablespoon (Canadian)",
  "Tablespoon (US) {tbsp}",
  "Tablespoon (metric)",
  "Tablespoon (Imperial)",
  "Teaspoon (Canadian)",
  "Teaspoon (U.S.) {tsp}",
  "Teaspoon (metric)",
  "Teaspoon (Imperial)",
  "Teraliter {Tl}",
  "Timber Foot",
  "Ton (Displacement)",
  "Ton (Water)",
  "Ton (Freight)",
  "Ton (Register)",
  "Tun",
  "Wey",
  "Yoctoliter {yl}",
  "Yottaliter {Yl}",
  "Zeptoliter {zl}",
  "Zettaliter {Zl}",
  NULL
};

char	*conv_masses[] = {
  "Atomic Mass Unit",
  "Atomic Mass Unit (Unified)",
  "Attogram {ag}",
  "Bag (Coffee)",
  "Bag (Portland Cement)",
  "Barge",
  "Carat {ct}",
  "Carat (metric) {kt}",
  "Cental",
  "Centigram {cg}",
  "Clove",
  "Crith",
  "Dalton {Da}",
  "Decagram {dag}",
  "Decigram {dg}",
  "Dram (Avoirdupois) {dr.Av}",
  "Dram (Apothecary) {dr.Ap}",
  "Electron Rest Mass {me}",
  "Exagram {Eg}",
  "Femtogram {fg}",
  "Gamma",
  "Geepound",
  "Gigagram {Gg}",
  "Grain {gr}",
  "Gram {g}",
  "Grave",
  "Hectogram {hg}",
  "hyl (CGS unit)",
  "hyl (MKS unit)",
  "Hundredweight (Short) {sh.Cwt}",
  "Hundredweight (Long) {l.Cwt}",
  "Kilogram {kg}",
  "Kip",
  "Mark",
  "Megagram {Mg}",
  "Microgram {µg}",
  "Milligram {mg}",
  "Mite",
  "Mite (metric)",
  "Nanogram {ng}",
  "Ounce (Avoirdupois) {oz}",
  "Ounce (Apothecary)",
  "Pennyweight {dwt}",
  "Petagram {Pg}",
  "Picogram {pg}",
  "Pound (Troy) {#}",
  "Pound (Avoirdupois) {lb}",
  "Pound (metric)",
  "Quintal (metric) {q}",
  "Quarter (Long)",
  "Quarter (Imperial) {qtr}",
  "Scruple (Avoirdupois)",
  "Sheet",
  "Slug",
  "Stone",
  "Teragram {Tg}",
  "Ton (Short Assay) {AT}",
  "Ton (Long Assay)",
  "Ton (Short) {sh.tn}",
  "Ton (Long) {long.tn.}",
  "Tonne / Metric Ton {MT}",
  "Wey",
  "Yoctogram {yg}",
  "Yottagram {Yg}",
  "Zeptogram {zg}",
  "Zettagram {Zg}",
  NULL
};


char	*conv_speeds[] = {
  "Centimeters/second {cm/s}",
  "Meters/second {m/s}",
  "Feet/second {f/s}",
  "Feet/minute {f/m}",
  "Feet/hour {fph}",
  "Furlongs/fortnight",
  "Furlongs/minute {fur/m}",
  "inches/minute {in/m}",
  "inches/second {in/s}",
  "Kilometers/hour {km/h}",
  "Knots {k}",
  "Knots (Admiralty)",
  "Leagues/day",
  "Mach (dry air, 273 kelvin) {Ma}",
  "Miles/second {mps}",
  "Miles/minute {mpm}",
  "Miles/hour {mph}",
  NULL
};


char	*conv_powers[] = {
  "Atmosphere Cubic Centimeter/minute {atm.ccm.}",
  "Atmosphere Cubic Centimeter/second {atm.ccs.",
  "Atmosphere Cubic foot/minute {atm.cfm.}",
  "Atmosphere Cubic foot/second {atm.cfs.}",
  "Attowatt {aW}",
  "BTU/hour",
  "BTU/s",
  "Calorie/second {cal/s}",
  "Centiwatt {cW}",
  "Decawatt {daW}",
  "Deciwatt {dW}",
  "Ergs/sec",
  "Exawatt {EW}",
  "Femtowatt {fW}",
  "Foot-lbs/hour {ft-lbf/h}",
  "Foot-lbs/minute {ft-lbf/m}",
  "Foot-lbs/sec {ft-lbf/s}",
  "Hectowatt {hW}",
  "Horsepower (metric) {hp}",
  "Horsepower (European electrical)",
  "Horsepower (Imperial mechanical)",
  "Horsepower (Imperial electrical)",
  "Horsepower (Boiler)",
  "Kilowatt {kW}",
  "Liter-atmosphere/minute {L-atm/min}",
  "Liter-atmosphere/sec {L-atm/s}",
  "Lusec",
  "Gigawatts {GW}",
  "Megawatt {MW}",
  "Microwatt {µW}",
  "Milliwatt {mW}",
  "Nanowatt {nW}",
  "Petawatt {PW}",
  "Picowatt {pW}",
  "Poncelet {p}",
  "Square Foot Equivalent Direct Radiation",
  "Terawatt {TW}",
  "Ton of A.C.}",
  "Ton of Refrigeration}",
  "Ton of Refrigeration (Imperial)",
  "Watts (joules/sec) {W}",
  "Yoctowatt {yW}",
  "Yottawatt {YW}",
  "Zeptowatt {zW}",
  "Zettawatt {ZW}",
  NULL
};


char	*conv_forces[] = {
  "Dyne {dyn}",
  "Grave-force {Gf}",
  "Gravet",
  "Kilopond {kp}",
  "Kilogram-force {kgf}",
  "Kip (kilopound-force)",
  "Milligrave-force {gf}",
  "Newton {N}",
  "Ounce-force {ozf}",
  "Pound {lbf}",
  "Poundal {pdl}",
  "Sthene {sn}",
  "Ton-force {tnf}",
  NULL
};


char	*conv_accelerations[] = {
  "Celo",
  "Centigal",
  "Centimeter/square second {cm/s2}",
  "Decigal {Dg}",
  "Foot/square second {f/s2}",
  "Foot/hour/second {f/h/s}",
  "Foot/minute/second {f/m/s}",
  "G-unit (G) {G}",
  "Galileo {Gal}",
  "Grav",
  "Inch/square second {in/s2}",
  "Inch/minute/second {in/m/s}",
  "Kilometer/hour/second {km/h/s}",
  "Kilometer/square second {km/s2}",
  "Knot/second {k/s}",
  "Leo",
  "Meter/square second {m/s2}",
  "Mile/hour/minute {mi/h/m}",
  "Mile/hour/second {mi/h/s}",
  "Mile/minute/second {mi/m/s}",
  "Mile/square second {mi/s2}",
  "Milligal {mGal}",
  "Millimeter/square second {mm/s2}",
  NULL
};


char	*conv_temperatures[] = {
  "Kelvin {K}",
  "Celsius {C}",
  "Rankine",
  "Farenheit {F}",
  "Reaumur {R}",
  NULL
};


char	*conv_angles[] = {
  "Angular Mil",
  "Arcminute",
  "Arcsecond",
  "Centesimal Minute of Arc",
  "Centesimal Second of Arc",
  "Degree {°}",
  "Gradian {grad}",
  "Octant",
  "Sextant",
  "Sign",
  "Radian {rad}",
  "Quadrant",
  NULL
};


char	*conv_pressures[] = {
  "Atmosphere (technical)",
  "Atmosphere (standard) {atm}",
  "Attopascal {aPa}",
  "Bar",
  "Barye",
  "Centimeter of Water (3.98°C)",
  "Centimeter of Mercury {cmHg}",
  "Centipascal {cPa}",
  "Decapascal {daPa}",
  "Decipascal {dPa}",
  "Exapascal {EPa}",
  "Femtopascal {fPa}",
  "Foot of Water (3.98°C)",
  "Foot of Mercury {ftHg}",
  "Gigapascal {GPa}",
  "Hectopascal {hPa",
  "Inch of Water (3.98°C)",
  "Inch of Mercury {inHg}",
  "Kilogram-force/sq.mm. {kgf/mm2}",
  "Kilopascal {kPa}",
  "kip/sq.in. {kip/sq.in.}",
  "Megapascal {MPa}",
  "Micropascal {µPa}",
  "Millimeter of Mercury {mmHg}",
  "Millimeter of Water (3.98°C)",
  "Millipascal {mPa}",
  "Nanopascal {nPa}",
  "Pascal {Pa}",
  "Petapascal {PPa}",
  "Picopascal {pPa}",
  "Pièze",
  "Poundal/sq.ft.",
  "Pound/sq.ft. {psf}",
  "Pound/sq.in. {psi}",
  "Short Ton/sq.ft.",
  "Terapascal {TPa}",
  "Torr",
  "Yoctopascal {yPa}",
  "Yottapascal {YPa}",
  "Zeptopascal {zPa}",
  "Zettapascal {ZPa}",
  NULL
};


conversion_type conversions[] = {
  {"Length",		conv_lengths},
  {"Area",		conv_areas},
  {"Volume",		conv_volumes},
  {"Mass",		conv_masses},
  {"Speed",		conv_speeds},
  {"Power",		conv_powers},
  {"Force",		conv_forces},
  {"Acceleration",	conv_accelerations},
  {"Temperature",	conv_temperatures},
  {"Angle",		conv_angles},
  {"Pressure",		conv_pressures},
  {NULL}
};

